@@ -230,19 +230,23 @@ class NotificationType(models.TextChoices):
     @classproperty
     def relevant_for_alliance_level(cls) -> set:
         return {
+            # sov
             cls.SOV_ENTOSIS_CAPTURE_STARTED,
             cls.SOV_COMMAND_NODE_EVENT_STARTED,
             cls.SOV_ALL_CLAIM_ACQUIRED_MSG,
             cls.SOV_STRUCTURE_REINFORCED,
             cls.SOV_STRUCTURE_DESTROYED,
+            # wars
             cls.WAR_ALLY_JOINED_WAR_AGGRESSOR_MSG,
+            cls.WAR_ALLY_JOINED_WAR_AllY_MSG,
+            cls.WAR_ALLY_JOINED_WAR_DEFENDER_MSG,
             cls.WAR_CORP_WAR_SURRENDER_MSG,
-            cls.WAR_WAR_DECLARED,
-            cls.WAR_WAR_RETRACTED_BY_CONCORD,
-            cls.WAR_WAR_ADOPTED,
-            cls.WAR_WAR_INHERITED,
             cls.WAR_CORPORATION_BECAME_ELIGIBLE,
             cls.WAR_CORPORATION_NO_LONGER_ELIGIBLE,
+            cls.WAR_WAR_ADOPTED,
+            cls.WAR_WAR_DECLARED,
+            cls.WAR_WAR_INHERITED,
+            cls.WAR_WAR_RETRACTED_BY_CONCORD,
         }
 
     @classproperty
@@ -531,7 +535,11 @@ class Notification(models.Model):
 
     def filter_for_alliance_level(self) -> bool:
         """True when notification to be filtered out due to alliance level."""
-        return self.is_alliance_level and not self.owner.is_alliance_main
+        return (
+            self.is_alliance_level
+            and self.owner.corporation.alliance is not None
+            and not self.owner.is_alliance_main
+        )
 
     def _generate_embed(
         self, language_code: str
